/*
* Copyright 2012 the original author or authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package groovyx.gaelyk.resources

/**
 * This class helps finding the proper MIME type based of the extension of the path.
 * The extension is taken as the part of the path from the last period to the end of the
 * string.
 * 
 * You can add or override mimetypes calling the {@link MimeTypes#addType(String, String)}
 * method for example in your plugin descriptor.
 * 
 * @author Vladimir Orany
 *
 */
class MimeTypes {
	
	static types = [
	'.3dm': 'x-world/x-3dmf',
	'.zsh': 'text/x-script.zsh',
	'.zip': 'application/zip',
	'.z': 'application/x-compressed',
	'.xyz': 'chemical/x-pdb',
	'.xwd': 'image/x-xwd',
	'.xsr': 'video/x-amt-showrun',
	'.xpm': 'image/xpm',
	'.xpix': 'application/x-vnd.ls-xpix',
	'.xmz': 'xgl/movie',
	'.xml': 'application/xml',
	'.xm': 'audio/xm',
	'.xlw': 'application/x-msexcel',
	'.xlw': 'application/x-excel',
	'.xlw': 'application/vnd.ms-excel',
	'.xlw': 'application/excel',
	'.xlv': 'application/x-excel',
	'.xlv': 'application/excel',
	'.xlt': 'application/x-excel',
	'.xlt': 'application/excel',
	'.xls': 'application/x-msexcel',
	'.xls': 'application/x-excel',
	'.xls': 'application/vnd.ms-excel',
	'.xls': 'application/excel',
	'.xlm': 'application/x-excel',
	'.xlm': 'application/vnd.ms-excel',
	'.xlm': 'application/excel',
	'.xll': 'application/x-excel',
	'.xll': 'application/vnd.ms-excel',
	'.xll': 'application/excel',
	'.xlk': 'application/x-excel',
	'.xlk': 'application/excel',
	'.xld': 'application/x-excel',
	'.xld': 'application/excel',
	'.xlc': 'application/x-excel',
	'.xlc': 'application/vnd.ms-excel',
	'.xlc': 'application/excel',
	'.xlb': 'application/x-excel',
	'.xlb': 'application/vnd.ms-excel',
	'.xlb': 'application/excel',
	'.xla': 'application/x-msexcel',
	'.xla': 'application/x-excel',
	'.xla': 'application/excel',
	'.xl': 'application/excel',
	'.xif': 'image/vnd.xiff',
	'.xgz': 'xgl/drawing',
	'.xdr': 'video/x-amt-demorun',
	'.xbm': 'image/xbm',
	'.xbm': 'image/x-xbm',
	'.xbm': 'image/x-xbitmap',
	'.x-png': 'image/png',
	'.wtk': 'application/x-wintalk',
	'.wsrc': 'application/x-wais-source',
	'.wsc': 'text/scriplet',
	'.wrz': 'x-world/x-vrml',
	'.wrz': 'model/vrml',
	'.wrl': 'x-world/x-vrml',
	'.wrl': 'model/vrml',
	'.wrl': 'application/x-world',
	'.wri': 'application/x-wri',
	'.wri': 'application/mswrite',
	'.wq1': 'application/x-lotus',
	'.wpd': 'application/x-wpwin',
	'.wpd': 'application/wordperfect',
	'.wp6': 'application/wordperfect',
	'.wp5': 'application/wordperfect6.0',
	'.wp5': 'application/wordperfect',
	'.wp': 'application/wordperfect',
	'.word': 'application/msword',
	'.wmlsc': 'application/vnd.wap.wmlscriptc',
	'.wmls': 'text/vnd.wap.wmlscript',
	'.wmlc': 'application/vnd.wap.wmlc',
	'.wml': 'text/vnd.wap.wml',
	'.wmf': 'windows/metafile',
	'.wk1': 'application/x-123',
	'.wiz': 'application/msword',
	'.web': 'application/vnd.xara',
	'.wbmp': 'image/vnd.wap.wbmp',
	'.wb1': 'application/x-qpro',
	'.wav': 'audio/x-wav',
	'.wav': 'audio/wav',
	'.w6w': 'application/msword',
	'.w61': 'application/wordperfect6.1',
	'.w60': 'application/wordperfect6.0',
	'.vsw': 'application/x-visio',
	'.vst': 'application/x-visio',
	'.vsd': 'application/x-visio',
	'.vrt': 'x-world/x-vrt',
	'.vrml': 'x-world/x-vrml',
	'.vrml': 'model/vrml',
	'.vrml': 'application/x-vrml',
	'.vql': 'audio/x-twinvq-plugin',
	'.vqf': 'audio/x-twinvq',
	'.vqe': 'audio/x-twinvq-plugin',
	'.vox': 'audio/voxware',
	'.vos': 'video/vosaic',
	'.voc': 'audio/x-voc',
	'.voc': 'audio/voc',
	'.vmf': 'application/vocaltec-media-file',
	'.vmd': 'application/vocaltec-media-desc',
	'.vivo': 'video/vnd.vivo',
	'.vivo': 'video/vivo',
	'.viv': 'video/vnd.vivo',
	'.viv': 'video/vivo',
	'.vew': 'application/groupwise',
	'.vdo': 'video/vdo',
	'.vda': 'application/vda',
	'.vcs': 'text/x-vcalendar',
	'.vcd': 'application/x-cdlink',
	'.uue': 'text/x-uuencode',
	'.uu': 'text/x-uuencode',
	'.ustar': 'multipart/x-ustar',
	'.ustar': 'application/x-ustar',
	'.uris': 'text/uri-list',
	'.uri': 'text/uri-list',
	'.unv': 'application/i-deas',
	'.unis': 'text/uri-list',
	'.uni': 'text/uri-list',
	'.uil': 'text/x-uil',
	'.txt': 'text/plain',
	'.turbot': 'image/florian',
	'.tsv': 'text/tab-separated-values',
	'.tsp': 'audio/tsplayer',
	'.tsp': 'application/dsptype',
	'.tsi': 'audio/tsp-audio',
	'.tr': 'application/x-troff',
	'.tiff': 'image/x-tiff',
	'.tiff': 'image/tiff',
	'.tif': 'image/x-tiff',
	'.tif': 'image/tiff',
	'.tgz': 'application/x-compressed',
	'.tgz': 'application/gnutar',
	'.text': 'text/plain',
	'.text': 'application/plain',
	'.texinfo': 'application/x-texinfo',
	'.texi': 'application/x-texinfo',
	'.tex': 'application/x-tex',
	'.tcsh': 'text/x-script.tcsh',
	'.tcl': 'text/x-script.tcl',
	'.tcl': 'application/x-tcl',
	'.tbk': 'application/x-tbook',
	'.tbk': 'application/toolbook',
	'.tar': 'application/x-tar',
	'.talk': 'text/x-speech',
	'.t': 'application/x-troff',
	'.swf': 'application/x-shockwave-flash',
	'.svr': 'x-world/x-svr',
	'.svr': 'application/x-world',
	'.svf': 'image/x-dwg',
	'.svf': 'image/vnd.dwg',
	'.sv4crc': 'application/x-sv4crc',
	'.sv4cpio': 'application/x-sv4cpio',
	'.stp': 'application/step',
	'.stl': 'application/x-navistyle',
	'.stl': 'application/vnd.ms-pki.stl',
	'.stl': 'application/sla',
	'.step': 'application/step',
	'.sst': 'application/vnd.ms-pki.certstore',
	'.ssm': 'application/streamingmedia',
	'.ssi': 'text/x-server-parsed-html',
	'.src': 'application/x-wais-source',
	'.sprite': 'application/x-sprite',
	'.spr': 'application/x-sprite',
	'.spl': 'application/futuresplash',
	'.spc': 'text/x-speech',
	'.spc': 'application/x-pkcs7-certificates',
	'.sol': 'application/solids',
	'.snd': 'audio/x-adpcm',
	'.snd': 'audio/basic',
	'.smil': 'application/smil',
	'.smi': 'application/smil',
	'.sl': 'application/x-seelogo',
	'.skt': 'application/x-koan',
	'.skp': 'application/x-koan',
	'.skm': 'application/x-koan',
	'.skd': 'application/x-koan',
	'.sit': 'application/x-stuffit',
	'.sit': 'application/x-sit',
	'.sid': 'audio/x-psid',
	'.shtml': 'text/x-server-parsed-html',
	'.shtml': 'text/html',
	'.shar': 'application/x-shar',
	'.shar': 'application/x-bsh',
	'.sh': 'text/x-script.sh',
	'.sh': 'application/x-shar',
	'.sh': 'application/x-sh',
	'.sh': 'application/x-bsh',
	'.sgml': 'text/x-sgml',
	'.sgml': 'text/sgml',
	'.sgm': 'text/x-sgml',
	'.sgm': 'text/sgml',
	'.set': 'application/set',
	'.sea': 'application/x-sea',
	'.sea': 'application/sea',
	'.sdr': 'application/sounder',
	'.sdp': 'application/x-sdp',
	'.sdp': 'application/sdp',
	'.sdml': 'text/plain',
	'.scm': 'video/x-scm',
	'.scm': 'text/x-script.scheme',
	'.scm': 'text/x-script.guile',
	'.scm': 'application/x-lotusscreencam',
	'.sbk': 'application/x-tbook',
	'.s3m': 'audio/s3m',
	'.s': 'text/x-asm',
	'.rv': 'video/vnd.rn-realvideo',
	'.rtx': 'text/richtext',
	'.rtx': 'application/rtf',
	'.rtf': 'text/richtext',
	'.rtf': 'application/x-rtf',
	'.rtf': 'application/rtf',
	'.rt': 'text/vnd.rn-realtext',
	'.rt': 'text/richtext',
	'.rpm': 'audio/x-pn-realaudio-plugin',
	'.rp': 'image/vnd.rn-realpix',
	'.roff': 'application/x-troff',
	'.rnx': 'application/vnd.rn-realplayer',
	'.rng': 'application/vnd.nokia.ringing-tone',
	'.rng': 'application/ringing-tones',
	'.rmp': 'audio/x-pn-realaudio',
	'.rmp': 'audio/x-pn-realaudio-plugin',
	'.rmm': 'audio/x-pn-realaudio',
	'.rmi': 'audio/mid',
	'.rm': 'audio/x-pn-realaudio',
	'.rm': 'application/vnd.rn-realmedia',
	'.rgb': 'image/x-rgb',
	'.rf': 'image/vnd.rn-realflash',
	'.rexx': 'text/x-script.rexx',
	'.rast': 'image/cmu-raster',
	'.ras': 'image/x-cmu-raster',
	'.ras': 'image/cmu-raster',
	'.ras': 'application/x-cmu-raster',
	'.ram': 'audio/x-pn-realaudio',
	'.ra': 'audio/x-realaudio',
	'.ra': 'audio/x-pn-realaudio',
	'.ra': 'audio/x-pn-realaudio-plugin',
	'.qtif': 'image/x-quicktime',
	'.qti': 'image/x-quicktime',
	'.qtc': 'video/x-qtc',
	'.qt': 'video/quicktime',
	'.qif': 'image/x-quicktime',
	'.qd3d': 'x-world/x-3dmf',
	'.qd3': 'x-world/x-3dmf',
	'.qcp': 'audio/vnd.qcelp',
	'.pyc': 'applicaiton/x-bytecode.python',
	'.py': 'text/x-script.phyton',
	'.pwz': 'application/vnd.ms-powerpoint',
	'.pvu': 'paleovu/x-pv',
	'.ps': 'application/postscript',
	'.prt': 'application/pro_eng',
	'.pre': 'application/x-freelance',
	'.ppz': 'application/mspowerpoint',
	'.ppt': 'application/x-mspowerpoint',
	'.ppt': 'application/vnd.ms-powerpoint',
	'.ppt': 'application/powerpoint',
	'.ppt': 'application/mspowerpoint',
	'.pps': 'application/vnd.ms-powerpoint',
	'.pps': 'application/mspowerpoint',
	'.ppm': 'image/x-portable-pixmap',
	'.ppa': 'application/vnd.ms-powerpoint',
	'.pov': 'model/x-pov',
	'.pot': 'application/vnd.ms-powerpoint',
	'.pot': 'application/mspowerpoint',
	'.pnm': 'image/x-portable-anymap',
	'.pnm': 'application/x-portable-anymap',
	'.png': 'image/png',
	'.pm5': 'application/x-pagemaker',
	'.pm4': 'application/x-pagemaker',
	'.pm': 'text/x-script.perl-module',
	'.pm': 'image/x-xpixmap',
	'.plx': 'application/x-pixclscript',
	'.pl': 'text/x-script.perl',
	'.pl': 'text/plain',
	'.pko': 'application/vnd.ms-pki.pko',
	'.pkg': 'application/x-newton-compatible-pkg',
	'.pict': 'image/pict',
	'.pic': 'image/pict',
	'.pgm': 'image/x-portable-greymap',
	'.pgm': 'image/x-portable-graymap',
	'.pfunk': 'audio/make',
	'.pfunk': 'audio/make.my.funk',
	'.pdf': 'application/pdf',
	'.pdb': 'chemical/x-pdb',
	'.pcx': 'image/x-pcx',
	'.pct': 'image/x-pict',
	'.pcl': 'application/x-pcl',
	'.pcl': 'application/vnd.hp-pcl',
	'.pbm': 'image/x-portable-bitmap',
	'.pas': 'text/pascal',
	'.part': 'application/pro_eng',
	'.p7s': 'application/pkcs7-signature',
	'.p7r': 'application/x-pkcs7-certreqresp',
	'.p7m': 'application/x-pkcs7-mime',
	'.p7m': 'application/pkcs7-mime',
	'.p7c': 'application/x-pkcs7-mime',
	'.p7c': 'application/pkcs7-mime',
	'.p7a': 'application/x-pkcs7-signature',
	'.p12': 'application/x-pkcs12',
	'.p12': 'application/pkcs-12',
	'.p10': 'application/x-pkcs10',
	'.p10': 'application/pkcs10',
	'.p': 'text/x-pascal',
	'.omcr': 'application/x-omcregerator',
	'.omcd': 'application/x-omcdatamaker',
	'.omc': 'application/x-omc',
	'.oda': 'application/oda',
	'.nvd': 'application/x-navidoc',
	'.nsc': 'application/x-conference',
	'.nix': 'application/x-mix-transfer',
	'.niff': 'image/x-niff',
	'.nif': 'image/x-niff',
	'.ncm': 'application/vnd.nokia.configuration-message',
	'.nc': 'application/x-netcdf',
	'.naplps': 'image/naplps',
	'.nap': 'image/naplps',
	'.mzz': 'application/x-vnd.audioexplosion.mzz',
	'.my': 'audio/make',
	'.mv': 'video/x-sgi-movie',
	'.ms': 'application/x-troff-ms',
	'.mrc': 'application/marc',
	'.mpx': 'application/x-project',
	'.mpv': 'application/x-project',
	'.mpt': 'application/x-project',
	'.mpp': 'application/vnd.ms-project',
	'.mpga': 'audio/mpeg',
	'.mpg': 'video/mpeg',
	'.mpg': 'audio/mpeg',
	'.mpeg': 'video/mpeg',
	'.mpe': 'video/mpeg',
	'.mpc': 'application/x-project',
	'.mpa': 'video/mpeg',
	'.mpa': 'audio/mpeg',
	'.mp3': 'video/x-mpeg',
	'.mp3': 'video/mpeg',
	'.mp3': 'audio/x-mpeg-3',
	'.mp3': 'audio/mpeg3',
	'.mp2': 'video/x-mpeq2a',
	'.mp2': 'video/x-mpeg',
	'.mp2': 'video/mpeg',
	'.mp2': 'audio/x-mpeg',
	'.mp2': 'audio/mpeg',
	'.movie': 'video/x-sgi-movie',
	'.mov': 'video/quicktime',
	'.moov': 'video/quicktime',
	'.mod': 'audio/x-mod',
	'.mod': 'audio/mod',
	'.mme': 'application/base64',
	'.mm': 'application/x-meme',
	'.mm': 'application/base64',
	'.mjpg': 'video/x-motion-jpeg',
	'.mjf': 'audio/x-vnd.audioexplosion.mjuicemediafile',
	'.mime': 'www/mime',
	'.mime': 'message/rfc822',
	'.mif': 'application/x-mif',
	'.mif': 'application/x-frame',
	'.midi': 'x-music/x-midi',
	'.midi': 'music/crescendo',
	'.midi': 'audio/x-midi',
	'.midi': 'audio/x-mid',
	'.midi': 'audio/midi',
	'.midi': 'application/x-midi',
	'.mid': 'x-music/x-midi',
	'.mid': 'music/crescendo',
	'.mid': 'audio/x-midi',
	'.mid': 'audio/x-mid',
	'.mid': 'audio/midi',
	'.mid': 'application/x-midi',
	'.mhtml': 'message/rfc822',
	'.mht': 'message/rfc822',
	'.me': 'application/x-troff-me',
	'.mcp': 'application/netmc',
	'.mcf': 'text/mcf',
	'.mcf': 'image/vasa',
	'.mcd': 'application/x-mathcad',
	'.mcd': 'application/mcad',
	'.mc$': 'application/x-magic-cap-package-1.0',
	'.mbd': 'application/mbedlet',
	'.mar': 'text/plain',
	'.map': 'application/x-navimap',
	'.man': 'application/x-troff-man',
	'.m3u': 'audio/x-mpequrl',
	'.m2v': 'video/mpeg',
	'.m2a': 'audio/mpeg',
	'.m1v': 'video/mpeg',
	'.m': 'text/x-m',
	'.m': 'text/plain',
	'.lzx': 'application/x-lzx',
	'.lzx': 'application/lzx',
	'.lzh': 'application/x-lzh',
	'.ltx': 'application/x-latex',
	'.lsx': 'text/x-la-asf',
	'.lst': 'text/plain',
	'.lsp': 'text/x-script.lisp',
	'.lsp': 'application/x-lisp',
	'.log': 'text/plain',
	'.lma': 'audio/x-nspaudio',
	'.lma': 'audio/nspaudio',
	'.list': 'text/plain',
	'.lha': 'application/x-lha',
	'.lha': 'application/lha',
	'.less': 'text/css',
	'.latex': 'application/x-latex',
	'.lam': 'audio/x-liveaudio',
	'.la': 'audio/x-nspaudio',
	'.la': 'audio/nspaudio',
	'.ksh': 'text/x-script.ksh',
	'.ksh': 'application/x-ksh',
	'.kar': 'music/x-karaoke',
	'.kar': 'audio/midi',
	'.jut': 'image/jutvision',
	'.js': 'text/javascript',
	'.jps': 'image/x-jps',
	'.jpg': 'image/pjpeg',
	'.jpg': 'image/jpeg',
	'.jpeg': 'image/pjpeg',
	'.jpeg': 'image/jpeg',
	'.jpe': 'image/pjpeg',
	'.jpe': 'image/jpeg',
	'.jfif': 'image/pjpeg',
	'.jfif': 'image/jpeg',
	'.jfif-tbnl': 'image/jpeg',
	'.jcm': 'application/x-java-commerce',
	'.java': 'text/x-java-source',
	'.java': 'text/plain',
	'.jav': 'text/x-java-source',
	'.jav': 'text/plain',
	'.jam': 'audio/x-jam',
	'.ivy': 'application/x-livescreen',
	'.ivr': 'i-world/i-vrml',
	'.iv': 'application/x-inventor',
	'.it': 'audio/it',
	'.isu': 'video/x-isvideo',
	'.ip': 'application/x-ip2',
	'.ins': 'application/x-internett-signup',
	'.inf': 'application/inf',
	'.imap': 'application/x-httpd-imap',
	'.ima': 'application/x-ima',
	'.igs': 'model/iges',
	'.igs': 'application/iges',
	'.iges': 'model/iges',
	'.iges': 'application/iges',
	'.iefs': 'image/ief',
	'.ief': 'image/ief',
	'.idc': 'text/plain',
	'.ico': 'image/x-icon',
	'.ice': 'x-conference/x-cooltalk',
	'.chat': 'application/x-chat',
	'.cha': 'application/x-chat',
	'.htx': 'text/html',
	'.htt': 'text/webviewhtml',
	'.htmls': 'text/html',
	'.html': 'text/html',
	'.htm': 'text/html',
	'.htc': 'text/x-component',
	'.hta': 'application/hta',
	'.hqx': 'application/x-mac-binhex40',
	'.hqx': 'application/x-binhex40',
	'.hqx': 'application/mac-binhex40',
	'.hqx': 'application/mac-binhex',
	'.hqx': 'application/binhex4',
	'.hqx': 'application/binhex',
	'.hpgl': 'application/vnd.hp-hpgl',
	'.hpg': 'application/vnd.hp-hpgl',
	'.hlp': 'application/x-winhelp',
	'.hlp': 'application/x-helpfile',
	'.hlp': 'application/hlp',
	'.hlb': 'text/x-script',
	'.hh': 'text/x-h',
	'.hh': 'text/plain',
	'.hgl': 'application/vnd.hp-hpgl',
	'.help': 'application/x-helpfile',
	'.hdf': 'application/x-hdf',
	'.h': 'text/x-h',
	'.h': 'text/plain',
	'.gzip': 'multipart/x-gzip',
	'.gzip': 'application/x-gzip',
	'.gz': 'application/x-gzip',
	'.gz': 'application/x-compressed',
	'.gtar': 'application/x-gtar',
	'.gss': 'application/x-gss',
	'.gsp': 'application/x-gsp',
	'.gsm': 'audio/x-gsm',
	'.gsd': 'audio/x-gsm',
	'.gl': 'video/x-gl',
	'.gl': 'video/gl',
	'.gif': 'image/gif',
	'.g3': 'image/g3fax',
	'.g': 'text/plain',
	'.funk': 'audio/make',
	'.frl': 'application/freeloader',
	'.fpx': 'image/vnd.net-fpx',
	'.fpx': 'image/vnd.fpx',
	'.for': 'text/x-fortran',
	'.for': 'text/plain',
	'.fmf': 'video/x-atomic3d-feature',
	'.flx': 'text/vnd.fmi.flexstor',
	'.flo': 'image/florian',
	'.fli': 'video/x-fli',
	'.fli': 'video/fli',
	'.fif': 'image/fif',
	'.fif': 'application/fractals',
	'.fdf': 'application/vnd.fdf',
	'.f90': 'text/x-fortran',
	'.f90': 'text/plain',
	'.f77': 'text/x-fortran',
	'.f': 'text/x-fortran',
	'.f': 'text/plain',
	'.evy': 'application/x-envoy',
	'.evy': 'application/envoy',
	'.etx': 'text/x-setext',
	'.es': 'application/x-esrehber',
	'.eps': 'application/postscript',
	'.env': 'application/x-envoy',
	'.elc': 'application/x-elc',
	'.elc': 'application/x-bytecode.elisp (compiled elisp)',
	'.el': 'text/x-script.elisp',
	'.dxr': 'application/x-director',
	'.dxf': 'image/x-dwg',
	'.dxf': 'image/vnd.dwg',
	'.dxf': 'application/dxf',
	'.dwg': 'image/x-dwg',
	'.dwg': 'image/vnd.dwg',
	'.dwg': 'application/acad',
	'.dwf': 'model/vnd.dwf',
	'.dwf': 'drawing/x-dwf (old)',
	'.dvi': 'application/x-dvi',
	'.dv': 'video/x-dv',
	'.drw': 'application/drafting',
	'.dp': 'application/commonground',
	'.dot': 'application/msword',
	'.doc': 'application/msword',
	'.dl': 'video/x-dl',
	'.dl': 'video/dl',
	'.dir': 'application/x-director',
	'.dif': 'video/x-dv',
	'.der': 'application/x-x509-ca-cert',
	'.def': 'text/plain',
	'.deepv': 'application/x-deepv',
	'.dcr': 'application/x-director',
	'.cxx': 'text/plain',
	'.css': 'text/css',
	'.csh': 'text/x-script.csh',
	'.csh': 'application/x-csh',
	'.crt': 'application/x-x509-user-cert',
	'.crt': 'application/x-x509-ca-cert',
	'.crt': 'application/pkix-cert',
	'.crl': 'application/pkix-crl',
	'.crl': 'application/pkcs-crl',
	'.cpt': 'application/x-cpt',
	'.cpt': 'application/x-compactpro',
	'.cpt': 'application/mac-compactpro',
	'.cpp': 'text/x-c',
	'.cpio': 'application/x-cpio',
	'.conf': 'text/plain',
	'.com': 'text/plain',
	'.coffee': 'text/coffeescript',
	'.class': 'application/x-java-class',
	'.class': 'application/java',
	'.class': 'application/java-byte-code',
	'.cer': 'application/x-x509-ca-cert',
	'.cer': 'application/pkix-cert',
	'.cdf': 'application/x-netcdf',
	'.cdf': 'application/x-cdf',
	'.cdf': 'application/cdf',
	'.cco': 'application/x-cocoa',
	'.ccad': 'application/clariscad',
	'.cc': 'text/x-c',
	'.cc': 'text/plain',
	'.cat': 'application/vnd.ms-pki.seccat',
	'.c++': 'text/plain',
	'.c': 'text/x-c',
	'.c': 'text/plain',
	'.bz2': 'application/x-bzip2',
	'.bz': 'application/x-bzip',
	'.bsh': 'application/x-bsh',
	'.boz': 'application/x-bzip2',
	'.book': 'application/book',
	'.boo': 'application/book',
	'.bmp': 'image/x-windows-bmp',
	'.bmp': 'image/bmp',
	'.bm': 'image/bmp',
	'.bin': 'application/x-macbinary',
	'.bin': 'application/x-binary',
	'.bin': 'application/macbinary',
	'.bin': 'application/mac-binary',
	'.bcpio': 'application/x-bcpio',
	'.avs': 'video/avs-video',
	'.avi': 'video/x-msvideo',
	'.avi': 'video/msvideo',
	'.avi': 'video/avi',
	'.avi': 'application/x-troff-msvideo',
	'.au': 'audio/x-au',
	'.au': 'audio/basic',
	'.asx': 'video/x-ms-asf',
	'.asx': 'video/x-ms-asf-plugin',
	'.asx': 'application/x-mplayer2',
	'.asp': 'text/asp',
	'.asm': 'text/x-asm',
	'.asf': 'video/x-ms-asf',
	'.art': 'image/x-jg',
	'.arj': 'application/arj',
	'.aps': 'application/mime',
	'.aos': 'application/x-nokia-9000-communicator-add-on-software',
	'.ani': 'application/x-navi-animation',
	'.aip': 'text/x-audiosoft-intra',
	'.aim': 'application/x-aim',
	'.aiff': 'audio/aiff',
	'.aifc': 'audio/aiff',
	'.aif': 'audio/aiff',
	'.ai': 'application/postscript',
	'.afl': 'video/animaflex',
	'.acgi': 'text/html',
	'.abc': 'text/vnd.abc',
	'.aas': 'application/x-authorware-seg',
	'.aam': 'application/x-authorware-map',
	'.aab': 'application/x-authorware-bin',
	'.3dmf': 'x-world/x-3dmf'] as HashMap

	static final String DEFAULT_TYPE = 'application/octet-stream'
	
	/**
	 * Finds the MIME type by the file extension.
	 * @param extension the file extension to query for the MIME type
	 * @return the mime type for given file extension or 'application/octet-stream' if not found
	 */
	static String getTypeByExt(String extension){
		String ext = extension
		if(!ext){
			return DEFAULT_TYPE
		}
		if(!ext.startsWith('.')){
			ext = '.' + ext;
		}
		return types[ext] ?: DEFAULT_TYPE
	}
	
	/**
	 * Finds the MIME type by given path.
	 * Threats the text from last period to end of the path as the file extension.
	 * @param path the path of the resource
	 * @return  mime type for given path or 'application/octet-stream' if not found
	 */
	static String getTypeByFile(String path){
		if(!path){
			return DEFAULT_TYPE
		}
		getTypeByExt path[path.lastIndexOf('.')..-1]
	}
	
	/**
	 * Adds new MIME type to the MIME types map.
	 * @param extension	file extension for given MIME type
	 * @param type the MIME type
	 * @return the old MIME type associated with given extensions or <code>null</code>
	 */
	static addType(String extension, String type){
		String ext = extension
		if(!ext || !type){
			return
		}
		if(!ext.startsWith('.')){
			ext = '.' + ext;
		}
		return types[ext] = type
	}
	
	

}
